@@ -25,7 +25,6 @@
 //!
 #include "codechal_hw.h"
 #include "codechal_setting.h"
-#include "mhw_cmd_reader.h"
 
 #define VDBOX_HUC_VDENC_BRC_INIT_KERNEL_DESCRIPTOR 4
 
@@ -50,6 +49,10 @@ CodechalHwInterface::CodechalHwInterface(
 {
     CODECHAL_HW_FUNCTION_ENTER;
 
+#if MHW_HWCMDPARSER_ENABLED
+    mhw::HwcmdParser::InitInstance(osInterface);
+#endif
+
     // Basic intialization
     m_osInterface = osInterface;
 
@@ -166,7 +169,7 @@ MOS_STATUS CodechalHwInterface::InitCacheabilityControlSettings(
         auto gtSysInfo = m_osInterface->pfnGetGtSystemInfo(m_osInterface);
         CODECHAL_HW_CHK_NULL_RETURN(gtSysInfo);
 
-        l3CachingEnabled = (gtSysInfo->L3BankCount != 0);
+        l3CachingEnabled = (gtSysInfo->L3BankCount != 0 || gtSysInfo->L3CacheSizeInKb != 0);
     }
 
     if (l3CachingEnabled)
@@ -426,7 +429,8 @@ MOS_STATUS CodechalHwInterface::GetHucStateCommandSize(
     uint32_t cpCmdsize        = 0;
     uint32_t cpPatchListSize  = 0;
 
-    if (m_hucInterface && (standard == CODECHAL_HEVC || standard == CODECHAL_CENC || standard == CODECHAL_VP9 || standard == CODECHAL_AVC))
+    if (m_hucInterface && (standard == CODECHAL_HEVC || standard == CODECHAL_CENC || standard == CODECHAL_VP9 
+        || standard == CODECHAL_AVC || standard == CODECHAL_MPEG2 || standard == CODECHAL_VC1 || standard == CODECHAL_JPEG))
     {
         CODECHAL_HW_CHK_STATUS_RETURN(m_hucInterface->GetHucStateCommandSize(
             mode, &hucCommandsSize, &hucPatchListSize, params));
@@ -510,6 +514,12 @@ MOS_STATUS CodechalHwInterface::GetVdencStateCommandsDataSize(
         commands += m_miInterface->GetMiFlushDwCmdSize();
         commands += m_miInterface->GetMiBatchBufferStartCmdSize();
     }
+    else if (standard == CODECHAL_RESERVED0)
+    {
+        commands += m_miInterface->GetMiFlushDwCmdSize();
+        commands += m_miInterface->GetMiBatchBufferStartCmdSize();
+        commands += m_sizeOfCmdBatchBufferEnd;
+    }
     else
     {
         MHW_ASSERTMESSAGE("Unsupported encode mode.");
@@ -713,8 +723,6 @@ MOS_STATUS CodechalHwInterface::AddVdencBrcImgBuffer(
     // Add batch buffer end insertion flag
     m_miInterface->AddBatchBufferEndInsertionFlag(constructedCmdBuf);
 
-    OVERRIDE_CMD_DATA(constructedCmdBuf.pCmdBase, constructedCmdBuf.iOffset);
-
     if (data)
     {
         m_osInterface->pfnUnlockResource(
@@ -1293,7 +1301,8 @@ MOS_STATUS CodechalHwInterface::SendHwSemaphoreWaitCmd(
     PMOS_RESOURCE                               semaMem,
     uint32_t                                    semaData,
     MHW_COMMON_MI_SEMAPHORE_COMPARE_OPERATION   opCode,
-    PMOS_COMMAND_BUFFER                         cmdBuffer)
+    PMOS_COMMAND_BUFFER                         cmdBuffer,
+    uint32_t                                  semaMemOffset)
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
@@ -1305,6 +1314,7 @@ MOS_STATUS CodechalHwInterface::SendHwSemaphoreWaitCmd(
     miSemaphoreWaitParams.bPollingWaitMode = true;
     miSemaphoreWaitParams.dwSemaphoreData = semaData;
     miSemaphoreWaitParams.CompareOperation = opCode;
+    miSemaphoreWaitParams.dwResourceOffset = semaMemOffset;
     eStatus = m_miInterface->AddMiSemaphoreWaitCmd(cmdBuffer, &miSemaphoreWaitParams);
 
     return eStatus;
