@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2019, Intel Corporation
+* Copyright (c) 2017-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -48,7 +48,7 @@ CodechalDecodeVp9G12 ::  ~CodechalDecodeVp9G12()
      }
      if (m_scalabilityState)
      {
-         CodecHalDecodeScalability_Destroy(m_scalabilityState);
+         CodecHalDecodeScalability_Destroy_G12(m_scalabilityState);
          MOS_FreeMemAndSetNull(m_scalabilityState);
      }
      //Note: virtual engine interface destroy is done in MOS layer
@@ -86,6 +86,17 @@ CodechalDecodeVp9G12::CodechalDecodeVp9G12(
     CODECHAL_DECODE_CHK_NULL_NO_STATUS_RETURN(m_osInterface);
 
     Mos_CheckVirtualEngineSupported(m_osInterface, true, true);
+
+#if (_DEBUG || _RELEASE_INTERNAL)
+    MOS_USER_FEATURE_VALUE_DATA userFeatureData;
+    MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
+    MOS_UserFeature_ReadValue_ID(
+        nullptr,
+        __MEDIA_USER_FEATURE_VALUE_DECODE_HISTOGRAM_DEBUG_ID,
+        &userFeatureData,
+        m_osInterface->pOsContext);
+    m_histogramDebug = userFeatureData.u32Data ? true : false;
+#endif
 }
 
 MOS_STATUS CodechalDecodeVp9G12::SetGpuCtxCreatOption(
@@ -106,7 +117,7 @@ MOS_STATUS CodechalDecodeVp9G12::SetGpuCtxCreatOption(
 
         if (static_cast<MhwVdboxMfxInterfaceG12 *>(m_mfxInterface)->IsScalabilitySupported())
         {
-            CODECHAL_DECODE_CHK_STATUS_RETURN(CodechalDecodeScalability_ConstructParmsForGpuCtxCreation(
+            CODECHAL_DECODE_CHK_STATUS_RETURN(CodechalDecodeScalability_ConstructParmsForGpuCtxCreation_g12(
                 m_scalabilityState,
                 (PMOS_GPUCTX_CREATOPTIONS_ENHANCED)m_gpuCtxCreatOpt,
                 codecHalSetting));
@@ -172,16 +183,22 @@ MOS_STATUS CodechalDecodeVp9G12 :: AllocateResourcesVariableSizes()
 
     CODECHAL_DECODE_FUNCTION_ENTER;
 
-    CODECHAL_DECODE_CHK_STATUS_RETURN(CodechalDecodeVp9 :: AllocateResourcesVariableSizes());
-
 #ifdef _MMC_SUPPORTED
-    if (m_mmc && m_mmc->IsMmcEnabled() && MEDIA_IS_WA(m_waTable, WaClearCcsVe) && 
-        !Mos_ResourceIsNull(&m_destSurface.OsResource) && 
+    // To WA invalid aux data caused HW issue when MMC on
+    if (m_mmc && m_mmc->IsMmcEnabled() && MEDIA_IS_WA(m_waTable, Wa_1408785368) &&
+        !Mos_ResourceIsNull(&m_destSurface.OsResource) &&
         m_destSurface.OsResource.bConvertedFromDDIResource)
     {
-        CODECHAL_DECODE_VERBOSEMESSAGE("Clear CCS by VE resolve before frame %d submission", m_frameNum);
-        CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnDecompResource(m_osInterface, &m_destSurface.OsResource));
-        CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSetGpuContext(m_osInterface, m_videoContext));
+        if (m_secureDecoder && m_secureDecoder->IsAuxDataInvalid(&m_destSurface.OsResource))
+        {
+            CODECHAL_DECODE_CHK_STATUS_RETURN(m_secureDecoder->InitAuxSurface(&m_destSurface.OsResource, false, true));
+        }
+        else
+        {
+            CODECHAL_DECODE_VERBOSEMESSAGE("Clear CCS by VE resolve before frame %d submission", m_frameNum);
+            CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnDecompResource(m_osInterface, &m_destSurface.OsResource));
+            CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSetGpuContext(m_osInterface, m_videoContext));
+        }
     }
 #endif
 
@@ -220,6 +237,8 @@ MOS_STATUS CodechalDecodeVp9G12 :: AllocateResourcesVariableSizes()
         m_frameSizeMaxAlloced = frameSizeMax;
     }
 
+    CODECHAL_DECODE_CHK_STATUS_RETURN(CodechalDecodeVp9 ::AllocateResourcesVariableSizes());
+
     return eStatus;
 }
 
@@ -229,7 +248,7 @@ MOS_STATUS CodechalDecodeVp9G12::InitSfcState()
 #ifdef _DECODE_PROCESSING_SUPPORTED
     // Check if SFC can be supported
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_sfcState->CheckAndInitialize(
-        (CODECHAL_DECODE_PROCESSING_PARAMS *)m_decodeParams.m_procParams, 
+        (DecodeProcessingParams *)m_decodeParams.m_procParams, 
         m_vp9PicParams, 
         m_scalabilityState));
 #endif
@@ -316,8 +335,21 @@ MOS_STATUS CodechalDecodeVp9G12 :: InitializeDecodeMode ()
         initParams.u32PicHeightInPixel = m_usFrameHeightAlignedMinBlk;
         initParams.format              = m_decodeParams.m_destSurface->Format;
         initParams.gpuCtxInUse         = GetVideoContext();
-        initParams.usingSecureDecode   = m_secureDecoder ? m_secureDecoder->IsSecureDecodeEnabled() : false;
-
+        initParams.usingSecureDecode   = (m_secureDecoder != nullptr);
+        if (m_decodeHistogram == nullptr)
+        {
+            initParams.usingHistogram = false;
+#if (_DEBUG || _RELEASE_INTERNAL)
+            if (m_histogramDebug)
+            {
+                initParams.usingHistogram = true;
+            }
+#endif
+        }
+        else
+        {
+            initParams.usingHistogram = true;
+        }
         CODECHAL_DECODE_CHK_STATUS_RETURN(CodecHalDecodeScalability_InitScalableParams_G12(
             m_scalabilityState,
             &initParams,
@@ -544,11 +576,29 @@ MOS_STATUS CodechalDecodeVp9G12::AddPicStateMhwCmds(
     if (m_vp9PicParams->PicFlags.fields.frame_type == CODEC_VP9_INTER_FRAME &&
         !m_vp9PicParams->PicFlags.fields.intra_only)
     {
+#ifdef _MMC_SUPPORTED
+        //Get each reference surface state and be recorded by skipMask if current surface state is mmc disabled
+        uint8_t skipMask = 0xf8;
         for (uint8_t i = 1; i < 4; i++)
         {
-#ifdef _MMC_SUPPORTED
             CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->SetSurfaceState(m_picMhwParams.SurfaceParams[i]));
+            if (m_picMhwParams.SurfaceParams[i]->mmcState == MOS_MEMCOMP_DISABLED)
+            {
+                skipMask |= (1 << (i - 1));
+            }
+        }
+        CODECHAL_DECODE_NORMALMESSAGE("MMC skip masK is %d\n", skipMask);
+        for (uint8_t i = 1; i < 4; i++)
+        {
+            //Set each ref surface state as MOS_MEMCOMP_MC to satisfy MmcEnable in AddHcpSurfaceCmd
+            //Because each ref surface state should be programmed as the same
+            //The actual mmc state is recorded by skipMask and set each ref surface too
+            m_picMhwParams.SurfaceParams[i]->mmcState    = MOS_MEMCOMP_MC;
+            m_picMhwParams.SurfaceParams[i]->mmcSkipMask = skipMask;
+        }
 #endif
+        for (uint8_t i = 1; i < 4; i++)
+        {
             CODECHAL_DECODE_CHK_STATUS_RETURN(m_hcpInterface->AddHcpSurfaceCmd(
                 cmdBuffer,
                 m_picMhwParams.SurfaceParams[i]));
@@ -617,7 +667,7 @@ MOS_STATUS CodechalDecodeVp9G12::SetFrameStates()
     {
         CODECHAL_DECODE_CHK_STATUS_RETURN(AllocateHistogramSurface());
 
-        ((CODECHAL_DECODE_PROCESSING_PARAMS*)m_decodeParams.m_procParams)->pHistogramSurface = m_histogramSurface;
+        ((DecodeProcessingParams *)m_decodeParams.m_procParams)->m_histogramSurface = m_histogramSurface;
 
         if(m_decodeHistogram)
             m_decodeHistogram->SetSrcHistogramSurface(m_histogramSurface);
@@ -746,6 +796,14 @@ MOS_STATUS CodechalDecodeVp9G12 :: DecodeStateLevel()
             CODECHAL_DECODE_CHK_STATUS_RETURN(StartStatusReport(
                 cmdBufferInUse));
         }
+        else
+        {
+            CODECHAL_DECODE_CHK_STATUS_RETURN(NullHW::StartPredicate(m_miInterface, cmdBufferInUse));
+        }
+    }
+    else
+    {
+        CODECHAL_DECODE_CHK_STATUS_RETURN(NullHW::StartPredicate(m_miInterface, cmdBufferInUse));
     }
 
     if (CodecHalDecodeScalabilityIsScalableMode(m_scalabilityState))
@@ -775,6 +833,16 @@ MOS_STATUS CodechalDecodeVp9G12 :: DecodeStateLevel()
             m_scalabilityState,
             m_vp9PicParams,
             &hcpTileCodingParam));
+        //insert 2 dummy VD_CONTROL_STATE packets with data=0 before every HCP_TILE_CODING
+        if (MEDIA_IS_WA(m_waTable, Wa_14010222001))
+        {
+            MHW_MI_VD_CONTROL_STATE_PARAMS vdCtrlParam;
+            MOS_ZeroMemory(&vdCtrlParam, sizeof(MHW_MI_VD_CONTROL_STATE_PARAMS));
+            for (int i = 0; i < 2; i++)
+            {
+                CODECHAL_DECODE_CHK_STATUS_RETURN(static_cast<MhwMiInterfaceG12 *>(m_miInterface)->AddMiVdControlStateCmd(cmdBufferInUse, &vdCtrlParam));
+            }
+        }
         CODECHAL_DECODE_CHK_STATUS_RETURN(static_cast<MhwVdboxHcpInterfaceG12*>(m_hcpInterface)->AddHcpTileCodingCmd(
             cmdBufferInUse,
             &hcpTileCodingParam));
@@ -827,6 +895,7 @@ MOS_STATUS CodechalDecodeVp9G12 :: DecodePrimitiveLevel()
             m_scalabilityState,
             &scdryCmdBuffer,
             &cmdBufferInUse));
+        CodecHalDecodeScalability_DecPhaseToSubmissionType_G12(m_scalabilityState,cmdBufferInUse);
     }
 
     // store CS ENGINE ID register
@@ -980,6 +1049,14 @@ MOS_STATUS CodechalDecodeVp9G12 :: DecodePrimitiveLevel()
                 decodeStatusReport,
                 cmdBufferInUse));
         }
+        else
+        {
+            CODECHAL_DECODE_CHK_STATUS_RETURN(NullHW::StopPredicate(m_miInterface, cmdBufferInUse));
+        }
+    }
+    else
+    {
+        CODECHAL_DECODE_CHK_STATUS_RETURN(NullHW::StopPredicate(m_miInterface, cmdBufferInUse));
     }
 
     MOS_ZeroMemory(&flushDwParams, sizeof(flushDwParams));
@@ -999,6 +1076,14 @@ MOS_STATUS CodechalDecodeVp9G12 :: DecodePrimitiveLevel()
 
     CODECHAL_DEBUG_TOOL(
 
+        if (m_histogramDebug && m_histogramSurface) {
+            CODECHAL_DECODE_CHK_STATUS_RETURN(m_debugInterface->DumpBuffer(
+                &m_histogramSurface->OsResource,
+                CodechalDbgAttr::attrSfcHistogram,
+                "_DEC",
+                256 * 4));
+        }
+
         if (CodecHalDecodeScalabilityIsScalableMode(m_scalabilityState)) {
             CODECHAL_DECODE_CHK_STATUS_RETURN(CodecHalDecodeScalability_DbgDumpCmdBuffer_G12(
                 this,
@@ -1049,14 +1134,14 @@ MOS_STATUS CodechalDecodeVp9G12 :: DecodePrimitiveLevel()
     if (MOS_VE_SUPPORTED(m_osInterface) && CodecHalDecodeScalabilityIsScalableMode(m_scalabilityState))
     {
         submitCommand = CodecHalDecodeScalabilityIsToSubmitCmdBuffer_G12(m_scalabilityState);
-        HalOcaInterface::On1stLevelBBEnd(scdryCmdBuffer, *m_osInterface->pOsContext);
+        HalOcaInterface::On1stLevelBBEnd(scdryCmdBuffer, *m_osInterface);
     }
     else
     {
-        HalOcaInterface::On1stLevelBBEnd(primCmdBuffer, *m_osInterface->pOsContext);
+        HalOcaInterface::On1stLevelBBEnd(primCmdBuffer, *m_osInterface);
     }
 
-    if (submitCommand || m_osInterface->phasedSubmission)
+    if (submitCommand)
     {
         uint32_t renderingFlags = m_videoContextUsesNullHw;
 
@@ -1070,7 +1155,6 @@ MOS_STATUS CodechalDecodeVp9G12 :: DecodePrimitiveLevel()
             && MOS_VE_SUPPORTED(m_osInterface)
             && CodecHalDecodeScalabilityIsScalableMode(m_scalabilityState))
         {
-            CodecHalDecodeScalability_DecPhaseToSubmissionType_G12(m_scalabilityState,cmdBufferInUse);
             CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(
                 m_osInterface,
                 cmdBufferInUse,
@@ -1181,6 +1265,10 @@ MOS_STATUS CodechalDecodeVp9G12 :: AllocateStandard (
 
     CODECHAL_DECODE_CHK_STATUS_RETURN(InitMmcState());
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+    m_debugInterface->SetSWCrcMode(true);
+#endif
+
     m_width                      = settings->width;
     m_height                     = settings->height;
     if (settings->lumaChromaDepth & CODECHAL_LUMA_CHROMA_DEPTH_8_BITS)
@@ -1229,7 +1317,8 @@ MOS_STATUS CodechalDecodeVp9G12 :: AllocateStandard (
                 this,
                 m_scalabilityState,
                 m_hwInterface,
-                false));
+                false,
+                settings));
         }
         else
         {
@@ -1261,65 +1350,3 @@ MOS_STATUS CodechalDecodeVp9G12 :: AllocateStandard (
 
     return eStatus;
 }
-
-MOS_STATUS CodechalDecodeVp9G12::SetCencBatchBuffer(
-    PMOS_COMMAND_BUFFER cmdBuffer)
-{
-    CODECHAL_DECODE_CHK_NULL_RETURN(cmdBuffer);
-
-    MHW_BATCH_BUFFER        batchBuffer;
-    MOS_ZeroMemory(&batchBuffer, sizeof(MHW_BATCH_BUFFER));
-    MOS_RESOURCE *resHeap = nullptr;
-    CODECHAL_DECODE_CHK_NULL_RETURN(resHeap = m_cencBuf->secondLvlBbBlock->GetResource());
-
-    batchBuffer.OsResource   = *resHeap;
-    batchBuffer.dwOffset     = m_cencBuf->secondLvlBbBlock->GetOffset() + VP9_CENC_PRIMITIVE_CMD_OFFSET_IN_DW * 4;
-    batchBuffer.iSize        = m_cencBuf->secondLvlBbBlock->GetSize() - VP9_CENC_PRIMITIVE_CMD_OFFSET_IN_DW * 4;
-    batchBuffer.bSecondLevel = true;
-#if (_DEBUG || _RELEASE_INTERNAL)
-    batchBuffer.iLastCurrent = batchBuffer.iSize;
-#endif  // (_DEBUG || _RELEASE_INTERNAL)
-
-    CODECHAL_DECODE_CHK_STATUS_RETURN(m_miInterface->AddMiBatchBufferStartCmd(
-        cmdBuffer,
-        &batchBuffer));
-
-    CODECHAL_DEBUG_TOOL(
-        CODECHAL_DECODE_CHK_STATUS_RETURN(m_debugInterface->Dump2ndLvlBatch(
-            &batchBuffer,
-            CODECHAL_NUM_MEDIA_STATES,
-            "_2ndLvlBatch_Pic_Cmd"));)
-
-    // Primitive level cmds should not be in BE phases
-    if (!(CodecHalDecodeScalabilityIsBEPhaseG12(m_scalabilityState) && MOS_VE_SUPPORTED(m_osInterface)))
-    {
-        batchBuffer.dwOffset = m_cencBuf->secondLvlBbBlock->GetOffset();
-        batchBuffer.iSize = VP9_CENC_PRIMITIVE_CMD_OFFSET_IN_DW * 4;
-        batchBuffer.bSecondLevel = true;
-#if (_DEBUG || _RELEASE_INTERNAL)
-        batchBuffer.iLastCurrent = batchBuffer.iSize;
-#endif  // (_DEBUG || _RELEASE_INTERNAL)
-
-        CODECHAL_DECODE_CHK_STATUS_RETURN(m_miInterface->AddMiBatchBufferStartCmd(
-            cmdBuffer,
-            &batchBuffer));
-
-        CODECHAL_DEBUG_TOOL(
-            CODECHAL_DECODE_CHK_STATUS_RETURN(m_debugInterface->Dump2ndLvlBatch(
-                &batchBuffer,
-                CODECHAL_NUM_MEDIA_STATES,
-                "_2ndLvlBatch_Primitive_Cmd"));)
-    }
-
-    // Update GlobalCmdBufId
-    MHW_MI_STORE_DATA_PARAMS miStoreDataParams;
-    MOS_ZeroMemory(&miStoreDataParams, sizeof(miStoreDataParams));
-    miStoreDataParams.pOsResource = m_cencBuf->resTracker;
-    miStoreDataParams.dwValue     = m_cencBuf->trackerId;
-    CODECHAL_DECODE_VERBOSEMESSAGE("dwCmdBufId = %d", miStoreDataParams.dwValue);
-    CODECHAL_DECODE_CHK_STATUS_RETURN(m_miInterface->AddMiStoreDataImmCmd(
-        cmdBuffer,
-        &miStoreDataParams));
-    return MOS_STATUS_SUCCESS;
-}
-
